@@ -762,7 +762,11 @@ class DcsConnection:
             t = datetime.now()
             return {"power": t.second * 100}
         else:
-            return self.__device__.getdata()
+            try:
+                return self.__device__.getdata()
+            except Exception as e:
+                logging.warning(str(id(self)) + " cannot get data. " + str(e))
+            
     
     def loadlogdata(self, time = None):
 
@@ -782,7 +786,11 @@ class DcsConnection:
             logging.warning(str(id(self)) + " device not found. getting dummy logData")
             self.__logData__ = {"i_power": t.second * 100, "time": time}
         else:
-            self.__logData__ = self.__device__.getlogdata(time)
+            try:
+                self.__logData__ = self.__device__.getlogdata(time)
+            except Exception as e:
+                logging.warning(str(id(self)) + " cannot get logdata. " + str(e))
+
         
         self.__logDataTimestamp__ = t
 
