@@ -134,9 +134,10 @@ class DeviceAcThor(ModbusTcpDevice):
         }       
         return data
 
-    def getlogdata(self):
+    def getlogdata(self, time = None):
 
         logdata={
+            "time": time,
             "device": self.__devicetype__,
             "fwversion": self.__firmwareversion__
         }       
