@@ -81,11 +81,6 @@ class DeviceDiscoverer:     #Singleton
             s.close()
             raise DeviceDiscovererException("Error sending broadcast:" + str(e), 3)
 
-        ## getting the hostname by socket.gethostname() method
-        hostname = socket.gethostname()
-        ## getting the IP address using socket.gethostbyname() method
-        ip_address = socket.gethostbyname(hostname)
-
         devices = []
         for i in range(20):
             logging.debug("Processing response %d", i)
@@ -94,7 +89,7 @@ class DeviceDiscoverer:     #Singleton
                 logging.debug("Response: " + str(response))
                 response_ip = response[1][0]
                 response_data = response[0]
-                if response_ip != ip_address:
+                if response_ip not in ips:
                     device = self.decoderesponse(response_data)
                     if device != None and device["identification"] == id:
                         devices.append(device)
